scoretools.PianoStaff
=====================

.. abjad-lineage:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff

.. autoclass:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.descendants
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.is_semantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.leaves
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.lineage
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.music
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.override
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.parent
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.parentage
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.prolation
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.set
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.spanners
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.start_offset
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.storage_format
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.timespan
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.context_name
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.is_parallel
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.append
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.index
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__add__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__ge__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__gt__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__iadd__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__imul__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__le__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__lt__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__radd__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff.__setitem__
   :noindex:
